summaryrefslogtreecommitdiffstats
path: root/akregator/src/akregator_part.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:59:01 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:59:01 -0600
commit716a5de8870d7c02bb4d0aed72f30291b17b763a (patch)
tree29e58b213ead28151ccf7eb33d12c968ea844120 /akregator/src/akregator_part.cpp
parent0e00c0a86a4c9d7e80c7b66d91940cc7dcb79f78 (diff)
downloadtdepim-716a5de8870d7c02bb4d0aed72f30291b17b763a.tar.gz
tdepim-716a5de8870d7c02bb4d0aed72f30291b17b763a.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'akregator/src/akregator_part.cpp')
-rw-r--r--akregator/src/akregator_part.cpp32
1 files changed, 16 insertions, 16 deletions
diff --git a/akregator/src/akregator_part.cpp b/akregator/src/akregator_part.cpp
index c6252690..7fece27a 100644
--- a/akregator/src/akregator_part.cpp
+++ b/akregator/src/akregator_part.cpp
@@ -146,7 +146,7 @@ Part::Part( TQWidget *parentWidget, const char * /*widgetName*/,
TQStringList storageParams;
- storageParams.append(TQString("taggingEnabled=%1").tqarg(Settings::showTaggingGUI() ? "true" : "false"));
+ storageParams.append(TQString("taggingEnabled=%1").arg(Settings::showTaggingGUI() ? "true" : "false"));
if (factory != 0)
{
@@ -168,7 +168,7 @@ Part::Part( TQWidget *parentWidget, const char * /*widgetName*/,
{
m_storage = Backend::StorageFactoryRegistry::self()->getFactory("dummy")->createStorage(storageParams);
- KMessageBox::error(parentWidget, i18n("Unable to load storage backend plugin \"%1\". No feeds are archived.").tqarg(Settings::archiveBackend()), i18n("Plugin error") );
+ KMessageBox::error(parentWidget, i18n("Unable to load storage backend plugin \"%1\". No feeds are archived.").arg(Settings::archiveBackend()), i18n("Plugin error") );
}
Filters::ArticleFilterList list;
@@ -194,7 +194,7 @@ Part::Part( TQWidget *parentWidget, const char * /*widgetName*/,
m_extension = new BrowserExtension(this, "ak_extension");
connect(m_view, TQT_SIGNAL(setWindowCaption(const TQString&)), this, TQT_SIGNAL(setWindowCaption(const TQString&)));
- connect(m_view, TQT_SIGNAL(seStatusBarText(const TQString&)), this, TQT_SIGNAL(seStatusBarText(const TQString&)));
+ connect(m_view, TQT_SIGNAL(setStatusBarText(const TQString&)), this, TQT_SIGNAL(setStatusBarText(const TQString&)));
connect(m_view, TQT_SIGNAL(setProgress(int)), m_extension, TQT_SIGNAL(loadingProgress(int)));
connect(m_view, TQT_SIGNAL(signalCanceled(const TQString&)), this, TQT_SIGNAL(canceled(const TQString&)));
connect(m_view, TQT_SIGNAL(signalStarted(KIO::Job*)), this, TQT_SIGNAL(started(KIO::Job*)));
@@ -232,7 +232,7 @@ Part::Part( TQWidget *parentWidget, const char * /*widgetName*/,
initFonts();
- RSS::FileRetriever::setUserAgent(TQString("Akregator/%1; librss/remnants").tqarg(AKREGATOR_VERSION));
+ RSS::FileRetriever::setUserAgent(TQString("Akregator/%1; librss/remnants").arg(AKREGATOR_VERSION));
}
void Part::loadPlugins()
@@ -432,7 +432,7 @@ bool Part::openFile()
copyFile(backup);
- KMessageBox::error(m_view, i18n("<qt>The standard feed list is corrupted (invalid XML). A backup was created:<p><b>%2</b></p></qt>").tqarg(backup), i18n("XML Parsing Error") );
+ KMessageBox::error(m_view, i18n("<qt>The standard feed list is corrupted (invalid XML). A backup was created:<p><b>%2</b></p></qt>").arg(backup), i18n("XML Parsing Error") );
}
if (!doc.setContent(listBackup))
@@ -447,7 +447,7 @@ bool Part::openFile()
TQString backup = m_file + "-backup." + TQString::number(TQDateTime::currentDateTime().toTime_t());
copyFile(backup);
- KMessageBox::error(m_view, i18n("<qt>The standard feed list is corrupted (no valid OPML). A backup was created:<p><b>%2</b></p></qt>").tqarg(backup), i18n("OPML Parsing Error") );
+ KMessageBox::error(m_view, i18n("<qt>The standard feed list is corrupted (no valid OPML). A backup was created:<p><b>%2</b></p></qt>").arg(backup), i18n("OPML Parsing Error") );
}
m_view->loadFeeds(createDefaultFeedList());
}
@@ -486,7 +486,7 @@ void Part::slotSaveFeedList()
if (file.open(IO_WriteOnly) == false)
{
//FIXME: allow to save the feedlist into different location -tpr 20041118
- KMessageBox::error(m_view, i18n("Access denied: cannot save feed list (%1)").tqarg(m_file), i18n("Write error") );
+ KMessageBox::error(m_view, i18n("Access denied: cannot save feed list (%1)").arg(m_file), i18n("Write error") );
return;
}
@@ -639,10 +639,10 @@ void Part::importFile(const KURL& url)
if (doc.setContent(TQByteArray(file.readAll())))
m_view->importFeeds(doc);
else
- KMessageBox::error(m_view, i18n("Could not import the file %1 (no valid OPML)").tqarg(filename), i18n("OPML Parsing Error") );
+ KMessageBox::error(m_view, i18n("Could not import the file %1 (no valid OPML)").arg(filename), i18n("OPML Parsing Error") );
}
else
- KMessageBox::error(m_view, i18n("The file %1 could not be read, check if it exists or if it is readable for the current user.").tqarg(filename), i18n("Read Error"));
+ KMessageBox::error(m_view, i18n("The file %1 could not be read, check if it exists or if it is readable for the current user.").arg(filename), i18n("Read Error"));
if (isRemote)
KIO::NetAccess::removeTempFile(filename);
@@ -656,7 +656,7 @@ void Part::exportFile(const KURL& url)
if ( file.exists() &&
KMessageBox::questionYesNo(m_view,
- i18n("The file %1 already exists; do you want to overwrite it?").tqarg(file.name()),
+ i18n("The file %1 already exists; do you want to overwrite it?").arg(file.name()),
i18n("Export"),
i18n("Overwrite"),
KStdGuiItem::cancel()) == KMessageBox::No )
@@ -664,7 +664,7 @@ void Part::exportFile(const KURL& url)
if ( !file.open(IO_WriteOnly) )
{
- KMessageBox::error(m_view, i18n("Access denied: cannot write to file %1").tqarg(file.name()), i18n("Write Error") );
+ KMessageBox::error(m_view, i18n("Access denied: cannot write to file %1").arg(file.name()), i18n("Write Error") );
return;
}
@@ -978,11 +978,11 @@ bool Part::tryToLock(const TQString& backendName)
"can cause the loss of archived articles and crashes at startup.</b> "
"You should disable the archive for now "
"unless you are sure that %2 is not already running.</qt>")
- .tqarg( programName, programName, backendName );
+ .arg( programName, programName, backendName );
// TQString::arg( st ) only replaces the first occurrence of %1
// with st while TQString::arg( s1, s2 ) replacess all occurrences
// of %1 with s1 and all occurrences of %2 with s2. So don't
// even think about changing the above to .tqarg( programName ).
else
msg = i18n("<qt>%1 seems to be running on another display on this "
"machine. <b>Running %1 and %2 at the same "
@@ -990,7 +990,7 @@ bool Part::tryToLock(const TQString& backendName)
"the loss of archived articles and crashes at startup.</b> "
"You should disable the archive for now "
"unless you are sure that %2 is not already running.</qt>")
- .tqarg( oldProgramName, programName, backendName );
+ .arg( oldProgramName, programName, backendName );
}
else
{
@@ -1001,7 +1001,7 @@ bool Part::tryToLock(const TQString& backendName)
"You should disable the archive for now "
"unless you are sure that it is "
"not already running on %2.</qt>")
- .tqarg( programName, oldHostName, backendName );
+ .arg( programName, oldHostName, backendName );
else
msg = i18n("<qt>%1 seems to be running on %3. <b>Running %1 and %2 at the "
"same time is not supported by the %4 backend and can cause "
@@ -1009,7 +1009,7 @@ bool Part::tryToLock(const TQString& backendName)
"You should disable the archive for now "
"unless you are sure that %1 is "
"not running on %3.</qt>")
- .tqarg( oldProgramName, programName, oldHostName, backendName );
+ .arg( oldProgramName, programName, oldHostName, backendName );
}
KCursorSaver idle( KBusyPtr::idle() );
@@ -978,11 +978,11 @@ bool Part::tryToLock(const TQString& backendName)
// with st while TQString::arg( s1, s2 ) replacess all occurrences
// of %1 with s1 and all occurrences of %2 with s2. So don't
- // even think about changing the above to .tqarg( programName ).
+ // even think about changing the above to .arg( programName ).
else
msg = i18n("<qt>%1 seems to be running on another display on this "